/**
 * @copyright Sister Software. All rights reserved.
 * @author Teffen Ellis, et al.
 * @license
 * See LICENSE file in the project root for full license information.
 */
import ts from 'typescript'
import { TSPathTransformer } from './transformers.mjs'
export declare function createTSNodeConfigHostParser(): ts.ParseConfigHost
/**
 * Reads a tsconfig.json file and returns the parsed result.
 */
export declare function readParsedTSConfig(
  pathToTSConfig: string,
  configHostParser?: ts.ParseConfigHost
): ts.ParsedCommandLine
/**
 * Cleans a given directory, creating it if it doesn't exist.
 */
export declare function cleanDirectory(directoryPath: string): Promise<void>
export declare function cleanTSBuildDirectory(tsConfig: ts.ParsedCommandLine): Promise<void>
export declare function reportDiagnostic(diagnostic: ts.Diagnostic): void
/**
 * Prints a diagnostic every time the watch status changes.
 * This is mainly for messages like "Starting compilation" or "Compilation completed".
 */
export declare function reportWatchStatusChanged(diagnostic: ts.Diagnostic): void
/**
 * Emits the result of the program with the transformer and formatter applied.
 * This is a convenience wrapper around the TypeScript API and can be replaced
 * with a custom implementation if needed.
 */
export type EmitWithTransformerFn = () => ts.EmitResult
export type WithTransformerEmit<T> = T & {
  emitWithTransformer: EmitWithTransformerFn
}
export interface SimpleProgramConfig {
  tsConfig: ts.ParsedCommandLine
  transformer?: TSPathTransformer
  writeFileCallback?: ts.WriteFileCallback
}
/**
 * Creates a file name mapping used to rewrite the output file names.
 */
export declare function _createFileNameMap(
  tsConfig: ts.ParsedCommandLine,
  transformer?: TSPathTransformer
): Map<string, string>
/**
 * Creates a TypeScript compiler that watches for changes and emits the result.
 * This is a convenience wrapper around the TypeScript API and can be replaced
 * with a custom implementation if needed.
 *
 * @see {@linkcode createSimpleTSProgram} for a non-watching compiler.
 */
export declare function createSimpleTSProgramWithWatcher({
  tsConfig,
  transformer,
  writeFileCallback,
}: SimpleProgramConfig): ts.WatchOfFilesAndCompilerOptions<ts.EmitAndSemanticDiagnosticsBuilderProgram>
/**
 * Creates a TypeScript compiler that emits the result.
 * This is a convenience wrapper around the TypeScript API and can be replaced
 * with a custom implementation if needed.
 *
 * @see {@linkcode createSimpleTSProgramWithWatcher} for a watching compiler.
 */
export declare function createSimpleTSProgram({
  tsConfig,
  transformer,
  writeFileCallback,
}: SimpleProgramConfig): WithTransformerEmit<ts.Program>
