/**
 * @copyright Sister Software. All rights reserved.
 * @author Teffen Ellis, et al.
 * @license
 * See LICENSE file in the project root for full license information.
 */
import type { Options as PrettierOptions } from 'prettier'
import ts from 'typescript'
/**
 * A collection of regular expressions that match TypeScript-related file extensions.
 */
export declare const FileExtensionPatterns: {
  /** File ends with `.js` */
  readonly JavaScript: RegExp
  /** File ends with `.js.map` */
  readonly JavaScriptMap: RegExp
  /** File ends with `.mjs` */
  readonly JavaScriptModule: RegExp
  /** File ends with `.js.map` */
  readonly JavaScriptModuleMap: RegExp
  /** File ends with .js or .mjs */
  readonly JavaScriptLike: RegExp
  /** File ends with `.ts` */
  readonly TypeScript: RegExp
  /** File ends with `.tsx` */
  readonly TypeScriptReact: RegExp
  readonly TypeScriptModule: RegExp
  /**
   * File ends with `.ts` or `.tsx` or `.mts`
   */
  readonly TypeScriptLike: RegExp
  /** File ends with `.d.ts` */
  readonly TypeScriptDeclaration: RegExp
  /** File ends with `.d.mts` */
  readonly TypeScriptDeclarationModule: RegExp
  /** File ends with `.d.ts` or `.d.mts` */
  readonly TypeScriptDeclarationLike: RegExp
}
export declare const SourceMappingURLPreamble = '//# sourceMappingURL='
/**
 * A pattern that matches a source mapping URL comment.
 */
export declare const SourceMappingURLPattern: RegExp
/**
 * Creates a source mapping URL comment.
 * @internal
 */
export declare function createSourceMappingURL(url: string): string
/**
 * Determines if the given file name is a TypeScript declaration file.
 */
export declare function isTypeScriptDeclarationLike(fileName: string): boolean
/**
 * Determines if the given file name is a JavaScript map file.
 */
export declare function isJavaScriptMap(fileName: string): boolean
/**
 * Determines if the given file name is a JavaScript module map file.
 */
export declare function isJavaScriptModuleMap(fileName: string): boolean
/**
 * Determines if the given file name is a TypeScript file.
 * Note that this does not include TypeScript declaration files.
 */
export declare function isTypeScriptLike(fileName: string): boolean
/**
 * Determines if the given file is formattable by Prettier.
 */
export declare function isFormattable(filePath: string): boolean
/**
 * Creates a TypeScript `writeFileCallback` that uses Prettier to format the file contents.
 * This is convenience wrapper around TypeScript's default `ts.sys.writeFile` function.
 * @see {@linkcode ts.sys.writeFile}
 */
export declare function createPrettierWriteFileCallback(
  prettierOverrides?: Partial<PrettierOptions>
): Promise<ts.WriteFileCallback>
