/**
 * @copyright Sister Software. All rights reserved.
 * @author Teffen Ellis, et al.
 * @license
 * See LICENSE file in the project root for full license information.
 */
import ts from 'typescript'
import { PathRewriterFn, PathRewriterRecord } from './common.mjs'
/**
 * Rewrites '.ts', '.mts', and '.tsx' files to '.mjs' files
 * @internal
 */
export declare const simpleESMRewriter: PathRewriterFn
/**
 * AST Transformer to rewrite any imported or exported paths.
 * This is typically used to rewrite relative imports into absolute imports,
 * or to rewrite imports to a different file extension.
 */
export declare class TSPathTransformer {
  rewriter: PathRewriterFn | PathRewriterRecord
  constructor(rewriter?: PathRewriterFn | PathRewriterRecord)
  /**
   * Rewrite a single file path.
   *
   * ```ts
   * transformer.rewriteFilePath(filePath)
   * ```
   */
  rewriteFilePath(filePath: string): string
  /**
   * Rewrite the file names of the given source files.
   *
   * ```ts
   * transformer.rewriteSourceFiles(program.getSourceFiles())
   * ```
   */
  rewriteSourceFiles(sourceFiles: readonly ts.SourceFile[]): void
  /**
   * Reshape the transformer into a TypeScript transformer factory.
   *
   * @returns A TypeScript transformer factory.
   */
  asTransformerFactory(): ts.CustomTransformerFactory
  /**
   * Rewrite the text of a single file.
   *
   * By default, this will rewrite the source map declaration to point to the new file name.
   */
  rewriteFileText(fileName: string, text: string): string
  asCustomTransformers({ afterBuiltIn, afterDeclarations }?: AsCustomTransformersOptions): ts.CustomTransformers
}
/**
 * Options for the `asCustomTransformers` method.
 */
export interface AsCustomTransformersOptions {
  afterBuiltIn?: boolean
  afterDeclarations?: boolean
}
